using AmqpTest.Amqp;
using AmqpTest.Configs;
using AmqpTest.Logs;
using Microsoft.Extensions.Configuration;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Newtonsoft.Json;
using Newtonsoft.Json.Serialization;
using Serilog;
using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Threading.Tasks;

namespace AmqpTest
{
	public class Program
	{
		public Program(IConfiguration configuration)
		{
			Configuration = configuration;
		}

		public static IConfiguration Configuration { get; set; }

		public static void Main(string[] args)
		{
			//ѡļappsetting.json
			var config = new ConfigurationBuilder()
				.SetBasePath(Directory.GetCurrentDirectory())
				.AddJsonFile("appsettings.json", optional: true, reloadOnChange: true)
				.Build();
			Log.Logger = new LoggerConfiguration()
				.ReadFrom.Configuration(config).Enrich.WithThreadInfo()
				.CreateLogger();

			try
			{
				Log.Information("Starting up");
				CreateHostBuilder(args).Build().Run();
			}
			catch (Exception ex)
			{
				Log.Fatal(ex, "Application start-up failed");
			}
			finally
			{
				Log.CloseAndFlush();
			}
		}

		public static IHostBuilder CreateHostBuilder(string[] args) =>
			Host.CreateDefaultBuilder(args)
				.UseSerilog()
				.ConfigureServices((hostContext, services) =>
				{
					var configuration = hostContext.Configuration;
					services.Configure<IotConfig>(configuration.GetSection("IOTConfig"));

					JsonSerializerSettings setting = new JsonSerializerSettings();
					JsonConvert.DefaultSettings = () =>
					{
						setting.DateFormatString = "yyyy-MM-dd HH:mm:ss";
						setting.ContractResolver = new CamelCasePropertyNamesContractResolver();
						setting.NullValueHandling = new NullValueHandling();

						return setting;
					};

					services.AddSingleton<AmqpSubscribe>();
					services.AddHostedService<Worker>();
				});
	}
}

